@@ -1,7 +1,7 @@
 __author__ = 'Altertech, https://www.altertech.com/'
 __copyright__ = 'Copyright (C) 2020 Altertech'
 __license__ = 'MIT'
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 # TODO: 2fa
 
@@ -766,7 +766,7 @@ def init(app,
     def init_db():
         from sqlalchemy import (MetaData, Table, Column, BigInteger, VARCHAR,
                                 JSON, CHAR, DateTime, ForeignKey, Index,
-                                Boolean)
+                                Boolean, Numeric)
         meta = MetaData()
         user = Table(
             'webauth_user', meta,
@@ -775,7 +775,9 @@ def init(app,
             Column('password', VARCHAR(64), nullable=True),
             Column('d_created', DateTime(timezone=True), nullable=False),
             Column('d_active', DateTime(timezone=True), nullable=True),
-            Column('confirmed', Boolean, nullable=False, server_default='0'))
+            Column('confirmed', Boolean, nullable=False, server_default='0'),
+            Column('otp', Numeric(2, 0), nullable=False, server_default='0'),
+            Column('otp_secret', CHAR(16), nullable=True))
         user_auth = Table(
             f'webauth_user_auth', meta,
             Column('id', BigInteger(), primary_key=True, autoincrement=True),
